<?php

use Botble\Blog\Models\Post;
use Botble\Blog\Supports\PostFormat;
use Illuminate\Http\Request;

register_sidebar([
    'id'          => 'footer_sidebar',
    'name'        => __('Footer sidebar'),
    'description' => __('Area for footer widgets'),
]);

register_page_template([
    'homepage' => __('Homepage'),
    'homepage2' => __('Homepage2'),
    'foodlist' => __('Food List'),
    'healthlist' => __('Health List'),
    'televisionlist' => __('Television List'),
    'awardslist' => __('Award List'),
    'achievementslist' => __('Achievements List'),
    'presslist' => __('Press List'),
    'bookslist' => __('Book List'),
    'articlelist' => __('Article List'),
    'vegetarianlist' => __('Vegetarian List'),
    'foodieblinddate' => __('Foodie Blind Date'),
    'international-worklist' => __('International-Work List'),
    'sitemap' => __('Sitemap'),
]);

if (is_plugin_active('blog')) {
    PostFormat::registerPostFormat([
        'video' => [
            'key'  => 'video',
            'icon' => 'fa fa-camera',
            'name' => __('Video'),
        ],
    ]);
}

Menu::addMenuLocation('second-menu', __('Second menu'))
    ->addMenuLocation('header-menu', __('Header Navigation'))->addMenuLocation('footer-menu', __('Footer Navigation'));

add_action(BASE_ACTION_META_BOXES, 'add_addition_fields_in_post_screen', 24, 2);

/**
 * @param string $context
 * @param \Botble\Base\Models\BaseModel $object
 * @throws \Illuminate\Contracts\Filesystem\FileNotFoundException
 */
function add_addition_fields_in_post_screen($context, $object)
{
    if (is_plugin_active('blog') && get_class($object) == Post::class && $context == 'advanced') {
        MetaBox::addMetaBox('additional_post_fields', __('Addition Information'), 'post_additional_fields',
            get_class($object),
            $context);
    }
}

/**
 * @return mixed
 * @throws \Illuminate\Contracts\Filesystem\FileNotFoundException
 */
function post_additional_fields()
{
    $videoLink = null;
    $pressName = null;
    $buynowLink = null;
    //$custompostDate = null;
    $orderPostHome = null;

    $args = func_get_args();
    if (!empty($args[0])) {
        $videoLink = MetaBox::getMetaData($args[0], 'video_link', true);
        $pressName = MetaBox::getMetaData($args[0], 'press_name', true);
        $buynowLink = MetaBox::getMetaData($args[0], 'buynow_link', true);
        
        $orderPostHome = MetaBox::getMetaData($args[0], 'custom_order_post_home', true);
    }

    return Theme::partial('post-fields', compact('videoLink','pressName','buynowLink','orderPostHome'));
}

add_action(BASE_ACTION_AFTER_CREATE_CONTENT, 'save_addition_post_fields', 230, 3);
add_action(BASE_ACTION_AFTER_UPDATE_CONTENT, 'save_addition_post_fields', 231, 3);

/**
 * @param string $type
 * @param Request $request
 * @param \Botble\Base\Models\BaseModel $object
 * @throws \Illuminate\Contracts\Filesystem\FileNotFoundException
 */
function save_addition_post_fields($type, $request, $object)
{
    if (is_plugin_active('blog') && get_class($object) == Post::class && $request->has('video_link')) {
        MetaBox::saveMetaBoxData($object, 'video_link', $request->input('video_link'));
        MetaBox::saveMetaBoxData($object, 'press_name', $request->input('press_name'));
        MetaBox::saveMetaBoxData($object, 'buynow_link', $request->input('buynow_link'));
        MetaBox::saveMetaBoxData($object, 'custom_order_post_home', $request->input('custom_order_post_home'));
        /*MetaBox::saveMetaBoxData($object, 'custom_postdate', $request->input('custom_postdate'));*/
    }
}

RvMedia::setUploadPathAndURLToPublic();

RvMedia::addSize('featured', 560, 380)->addSize('medium', 540, 360);

if (is_plugin_active('ads')) {
    AdsManager::registerLocation('header', 'Header')
        ->registerLocation('top-sidebar', 'Top sidebar')
        ->registerLocation('bottom-sidebar', 'Bottom sidebar')
        ->registerLocation('top-single-page', 'Top single page')
        ->registerLocation('bottom-single-page', 'Bottom single page')
        ->registerLocation('before-featured-posts', 'Before featured posts')
        ->registerLocation('after-featured-posts', 'After featured posts')
        ->registerLocation('before-category-posts', 'Before category posts')
        ->registerLocation('after-category-posts', 'After category posts')
        ->registerLocation('before-galleries', 'Before galleries')
        ->registerLocation('after-galleries', 'After galleries');
}
